==> haskell-monadrandom-0.6.2-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MonadRandom
version:              0.6.2
visibility:           public
id:                   MonadRandom-0.6.2-5WPr3bd2QkWGqvsSijwFyD
key:                  MonadRandom-0.6.2-5WPr3bd2QkWGqvsSijwFyD
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  ad1e6a77a9fb74202f96a3e59647d8a5
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monadrandom
hs-libraries:         HSMonadRandom-0.6.2-5WPr3bd2QkWGqvsSijwFyD
depends:
    base-4.17.2.1 mtl-2.2.2 primitive-0.9.1.0-GChnkqMWBe7B15Z0K3IGlf
    random-1.2.1.3-1epqCSzcS4p5bPWcI4Ab0S transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadrandom-0.6.2-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MonadRandom
version:              0.6.2
visibility:           public
id:                   MonadRandom-0.6.2-Ev1BfkETMuD28N5lVmzr3e
key:                  MonadRandom-0.6.2-Ev1BfkETMuD28N5lVmzr3e
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  082b5ae96556af0ca9c48f8874b6ca4f
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monadrandom
hs-libraries:         HSMonadRandom-0.6.2-Ev1BfkETMuD28N5lVmzr3e
depends:
    base-4.17.2.1 mtl-2.2.2 primitive-0.9.1.0-3MsYNTRfRHtDQ9eN2n6le5
    random-1.2.1.3-9I8x2ZdyyN6LUBxcAUCXuW transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
